# iemap-module

This module provides simple functions to interact with the iemap API. 

## Quickstart
1. Create a virtual environment and install the module in it:
    ```bash
    pip install iemap
    ```

2. In your script or notebook, import the module:
    ```python
    import iemap
    ```

